@@ -1,11 +1,7 @@
 from typing import Optional
 
 from django import forms
-from django.contrib.auth import (
-    REDIRECT_FIELD_NAME,
-    get_user_model,
-    password_validation,
-)
+from django.contrib.auth import REDIRECT_FIELD_NAME, get_user_model, password_validation
 from django.contrib.auth.tokens import PasswordResetTokenGenerator
 from django.core import exceptions, validators
 from django.template.exceptions import TemplateDoesNotExist
@@ -17,10 +13,11 @@ from django.utils.translation import gettext, gettext_lazy as _, pgettext
 from allauth.account.app_settings import LoginMethod
 from allauth.account.fields import EmailField, PasswordField, SetPasswordField
 from allauth.account.internal import flows
-from allauth.account.internal.flows.manage_email import email_already_exists
-from allauth.account.internal.flows.phone_verification import (
-    phone_already_exists,
+from allauth.account.internal.flows.manage_email import (
+    email_already_exists,
+    sync_user_email_address,
 )
+from allauth.account.internal.flows.phone_verification import phone_already_exists
 from allauth.account.internal.flows.signup import base_signup_form_class
 from allauth.core import context, ratelimit
 from allauth.core.internal.cryptokit import compare_user_code
@@ -33,7 +30,6 @@ from .models import EmailAddress, Login
 from .utils import (
     filter_users_by_email,
     setup_user_email,
-    sync_user_email_addresses,
     url_str_to_user_pk,
     user_email,
     user_username,
@@ -43,7 +39,7 @@ from .utils import (
 class EmailAwarePasswordResetTokenGenerator(PasswordResetTokenGenerator):
     def _make_hash_value(self, user, timestamp):
         ret = super()._make_hash_value(user, timestamp)
-        sync_user_email_addresses(user)
+        sync_user_email_address(user)
         email = user_email(user)
         emails = set([email] if email else [])
         emails.update(
@@ -134,7 +130,7 @@ class LoginForm(forms.Form):
             return
         try:
             self.fields["password"].help_text = render_to_string(
-                "account/password_reset_help_text." + app_settings.TEMPLATE_EXTENSION
+                f"account/password_reset_help_text.{app_settings.TEMPLATE_EXTENSION}"
             )
             return
         except TemplateDoesNotExist:
@@ -225,7 +221,7 @@ class LoginForm(forms.Form):
             login_method = flows.login.derive_login_method(
                 login=self.cleaned_data["login"]
             )
-            raise adapter.validation_error("%s_password_mismatch" % login_method.value)
+            raise adapter.validation_error(f"{login_method.value}_password_mismatch")
         return self.cleaned_data
 
     def login(self, request, redirect_url=None):
@@ -439,10 +435,6 @@ class BaseSignupForm(base_signup_form_class()):  # type: ignore[misc]
         adapter = get_adapter()
         user = adapter.new_user(request)
         adapter.save_user(request, user, self)
-        if self._has_phone_field:
-            phone = self.cleaned_data.get("phone")
-            if phone:
-                adapter.set_phone(user, phone, False)
         self.custom_signup(request, user)
         # TODO: Move into adapter `save_user` ?
         setup_user_email(request, user, [EmailAddress(email=email)] if email else [])
@@ -581,7 +573,9 @@ class AddEmailForm(UserForm):
             email_address = EmailAddress(
                 user=self.user, email=self.cleaned_data["email"]
             )
-            email_address.send_confirmation(request)
+            flows.email_verification.send_verification_email_to_address(
+                request, email_address
+            )
             return email_address
         elif app_settings.CHANGE_EMAIL:
             return EmailAddress.objects.add_new_email(
