@@ -1,3 +1,6 @@
+from typing import Optional
+
+
 class AppSettings:
     def __init__(self, prefix):
         self.prefix = prefix
@@ -5,7 +8,7 @@ class AppSettings:
     def _setting(self, name, dflt):
         from allauth.utils import get_setting
 
-        return get_setting(self.prefix + name, dflt)
+        return get_setting(f"{self.prefix}{name}", dflt)
 
     @property
     def ADAPTER(self):
@@ -26,6 +29,10 @@ class AppSettings:
     def ACCESS_TOKEN_EXPIRES_IN(self) -> int:
         return self._setting("ACCESS_TOKEN_EXPIRES_IN", 3600)
 
+    @property
+    def ACCESS_TOKEN_FORMAT(self) -> str:
+        return self._setting("ACCESS_TOKEN_FORMAT", "opaque")
+
     @property
     def AUTHORIZATION_CODE_EXPIRES_IN(self) -> int:
         return self._setting("AUTHORIZATION_CODE_EXPIRES_IN", 60)
@@ -67,6 +74,15 @@ class AppSettings:
         """
         return self._setting("RP_INITIATED_LOGOUT_ASKS_FOR_OP_LOGOUT", True)
 
+    @property
+    def USERINFO_ENDPOINT(self) -> Optional[str]:
+        """
+        This setting can be used to point the ``userinfo_endpoint`` value as
+        returned in the ".well-known/openid-configuration" to a custom URL.
+        Setting this disables the built-in userinfo endpoint.
+        """
+        return self._setting("USERINFO_ENDPOINT", None)
+
 
 _app_settings = AppSettings("IDP_OIDC_")
 
