@@ -1,12 +1,11 @@
+from typing import Optional
+
 from django.forms import ValidationError
 
 from allauth.account import app_settings as account_settings
 from allauth.account.adapter import get_adapter as get_account_adapter
 from allauth.account.internal.flows.manage_email import assess_unique_email
-from allauth.account.internal.flows.signup import (
-    complete_signup,
-    prevent_enumeration,
-)
+from allauth.account.internal.flows.signup import complete_signup, prevent_enumeration
 from allauth.account.utils import user_username
 from allauth.core.exceptions import SignupClosedException
 from allauth.core.internal.httpkit import headed_redirect_response
@@ -15,10 +14,13 @@ from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.models import SocialLogin
 
 
-def get_pending_signup(request):
-    data = request.session.get("socialaccount_sociallogin")
-    if data:
-        return SocialLogin.deserialize(data)
+def get_pending_signup(request) -> Optional[SocialLogin]:
+    if data := request.session.get("socialaccount_sociallogin"):
+        try:
+            return SocialLogin.deserialize(data)
+        except ValueError:
+            return None
+    return None
 
 
 def redirect_to_signup(request, sociallogin):
@@ -42,6 +44,14 @@ def process_auto_signup(request, sociallogin):
     auto_signup = get_adapter().is_auto_signup_allowed(request, sociallogin)
     if not auto_signup:
         return False, None
+    auto_signup, resp = process_auto_signup_email(request, sociallogin)
+    if not auto_signup:
+        return False, resp
+    auto_signup, resp = process_auto_signup_phone(request, sociallogin)
+    return auto_signup, resp
+
+
+def process_auto_signup_email(request, sociallogin):
     email = None
     if sociallogin.email_addresses:
         email = sociallogin.email_addresses[0].email
@@ -50,7 +60,7 @@ def process_auto_signup(request, sociallogin):
         assessment = assess_unique_email(email)
         if assessment is True:
             # Auto signup is fine.
-            pass
+            auto_signup = True
         elif assessment is False:
             # Oops, another user already has this address.  We cannot simply
             # connect this social account to the existing user. Reason is
@@ -70,14 +80,31 @@ def process_auto_signup(request, sociallogin):
             # address. Instead, we're going to send the user an email that
             # the account already exists, and on the outside make it appear
             # as if an email verification mail was sent.
-            resp = prevent_enumeration(request, email)
+            resp = prevent_enumeration(request, email=email)
             return False, resp
     elif app_settings.EMAIL_REQUIRED:
         # Nope, email is required and we don't have it yet...
         auto_signup = False
+    else:
+        auto_signup = True
     return auto_signup, None
 
 
+def process_auto_signup_phone(request, sociallogin):
+    # At this point, email is not required, or, we have a unique email.  Let's
+    # check the phone number.
+    phone_field = account_settings.SIGNUP_FIELDS.get("phone")
+    if not phone_field or not phone_field["required"]:
+        return True, None
+    if not sociallogin.phone:
+        return False, None
+    # If the phone is already taken?
+    existing_user = get_account_adapter().get_user_by_phone(sociallogin.phone)
+    if existing_user:
+        return False, None
+    return True, None
+
+
 def process_signup(request, sociallogin):
     if not get_adapter().is_open_for_signup(request, sociallogin):
         raise SignupClosedException()
@@ -105,6 +132,9 @@ def process_signup(request, sociallogin):
 
 
 def complete_social_signup(request, sociallogin):
+    from allauth.socialaccount.internal.flows.login import record_authentication
+
+    record_authentication(request, sociallogin)
     return complete_signup(
         request,
         user=sociallogin.user,
