@@ -13,26 +13,18 @@ class AgaveAdapter(OAuth2Adapter):
     settings = app_settings.PROVIDERS.get(provider_id, {})
     provider_base_url = settings.get("API_URL", "https://public.agaveapi.co")
 
-    access_token_url = "{0}/token".format(provider_base_url)
-    authorize_url = "{0}/authorize".format(provider_base_url)
-    profile_url = "{0}/profiles/v2/me".format(provider_base_url)
+    access_token_url = f"{provider_base_url}/token"
+    authorize_url = f"{provider_base_url}/authorize"
+    profile_url = f"{provider_base_url}/profiles/v2/me"
 
     def complete_login(self, request, app, token, response):
-        extra_data = (
-            get_adapter()
-            .get_requests_session()
-            .get(
+        with get_adapter().get_requests_session() as sess:
+            extra_data = sess.get(
                 self.profile_url,
                 params={"access_token": token.token},
-                headers={
-                    "Authorization": "Bearer " + token.token,
-                },
+                headers={"Authorization": f"Bearer {token.token}"},
             )
-        )
-
-        user_profile = (
-            extra_data.json()["result"] if "result" in extra_data.json() else {}
-        )
+            user_profile = extra_data.json().get("result", {})
 
         return self.get_provider().sociallogin_from_response(request, user_profile)
 
