@@ -8,7 +8,7 @@ from allauth.socialaccount.providers.oauth2.urls import default_urlpatterns
 urlpatterns = default_urlpatterns(AppleProvider)
 urlpatterns += [
     path(
-        AppleProvider.get_slug() + "/login/callback/finish/",
+        f"{AppleProvider.get_slug()}/login/callback/finish/",
         oauth2_finish_login,
         name="apple_finish_callback",
     ),
