@@ -13,12 +13,9 @@ class AsanaOAuth2Adapter(OAuth2Adapter):
     profile_url = "https://app.asana.com/api/1.0/users/me"
 
     def complete_login(self, request, app, token, **kwargs):
-        resp = (
-            get_adapter()
-            .get_requests_session()
-            .get(self.profile_url, params={"access_token": token.token})
-        )
-        extra_data = resp.json()["data"]
+        with get_adapter().get_requests_session() as sess:
+            resp = sess.get(self.profile_url, params={"access_token": token.token})
+            extra_data = resp.json()["data"]
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
