@@ -1,4 +1,5 @@
 from allauth.socialaccount.adapter import get_adapter
+from allauth.socialaccount.models import SocialToken
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
     OAuth2CallbackView,
@@ -8,20 +9,19 @@ from allauth.socialaccount.providers.oauth2.views import (
 
 class AtlassianOAuth2Adapter(OAuth2Adapter):
     provider_id = "atlassian"
-    access_token_url = "https://api.atlassian.com/oauth/token"
+    access_token_url = "https://api.atlassian.com/oauth/token"  # nosec
     authorize_url = "https://auth.atlassian.com/authorize"
     profile_url = "https://api.atlassian.com/me"
 
-    def complete_login(self, request, app, access_token, **kwargs):
+    def complete_login(self, request, app, token: SocialToken, **kwargs):
         headers = {
-            "Authorization": f"Bearer {access_token}",
+            "Authorization": f"Bearer {token.token}",
             "Accept": "application/json",
         }
-        response = (
-            get_adapter().get_requests_session().get(self.profile_url, headers=headers)
-        )
-        response.raise_for_status()
-        data = response.json()
+        with get_adapter().get_requests_session() as sess:
+            response = sess.get(self.profile_url, headers=headers)
+            response.raise_for_status()
+            data = response.json()
         return self.get_provider().sociallogin_from_response(request, data)
 
 
