@@ -13,11 +13,10 @@ class DoximityOAuth2Adapter(OAuth2Adapter):
     profile_url = "https://www.doximity.com/api/v1/users/current"
 
     def complete_login(self, request, app, token, **kwargs):
-        headers = {"Authorization": "Bearer %s" % token.token}
-        resp = (
-            get_adapter().get_requests_session().get(self.profile_url, headers=headers)
-        )
-        extra_data = resp.json()
+        headers = {"Authorization": f"Bearer {token.token}"}
+        with get_adapter().get_requests_session() as sess:
+            resp = sess.get(self.profile_url, headers=headers)
+            extra_data = resp.json()
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
