@@ -13,16 +13,12 @@ class DropboxOAuth2Adapter(OAuth2Adapter):
     profile_url = "https://api.dropbox.com/2/users/get_current_account"
 
     def complete_login(self, request, app, token, **kwargs):
-        response = (
-            get_adapter()
-            .get_requests_session()
-            .post(
-                self.profile_url,
-                headers={"Authorization": "Bearer %s" % (token.token,)},
-            )
-        )
-        response.raise_for_status()
-        return self.get_provider().sociallogin_from_response(request, response.json())
+        headers = {"Authorization": f"Bearer {token.token}"}
+        with get_adapter().get_requests_session() as sess:
+            response = sess.post(self.profile_url, headers=headers)
+            response.raise_for_status()
+            extra_data = response.json()
+        return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
 oauth_login = OAuth2LoginView.adapter_view(DropboxOAuth2Adapter)
