@@ -8,17 +8,14 @@ from allauth.socialaccount.providers.oauth2.views import (
 
 class EdmodoOAuth2Adapter(OAuth2Adapter):
     provider_id = "edmodo"
-    access_token_url = "https://api.edmodo.com/oauth/token"
+    access_token_url = "https://api.edmodo.com/oauth/token"  # nosec
     authorize_url = "https://api.edmodo.com/oauth/authorize"
     profile_url = "https://api.edmodo.com/users/me"
 
     def complete_login(self, request, app, token, **kwargs):
-        resp = (
-            get_adapter()
-            .get_requests_session()
-            .get(self.profile_url, params={"access_token": token.token})
-        )
-        extra_data = resp.json()
+        with get_adapter().get_requests_session() as sess:
+            resp = sess.get(self.profile_url, params={"access_token": token.token})
+            extra_data = resp.json()
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
