@@ -7,7 +7,7 @@ from allauth.socialaccount.providers.oauth.provider import OAuthProvider
 
 class FiveHundredPxAccount(ProviderAccount):
     def get_profile_url(self):
-        return "https://500px.com/%s" % self.account.extra_data.get("username")
+        return f"https://500px.com/{self.account.extra_data.get('username')}"
 
     def get_avatar_url(self):
         return self.account.extra_data.get("userpic_url")
