@@ -1,13 +1,11 @@
 from allauth.socialaccount.providers.base import ProviderAccount
-from allauth.socialaccount.providers.foursquare.views import (
-    FoursquareOAuth2Adapter,
-)
+from allauth.socialaccount.providers.foursquare.views import FoursquareOAuth2Adapter
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
 
 class FoursquareAccount(ProviderAccount):
     def get_profile_url(self):
-        return "https://foursquare.com/user/" + self.account.extra_data.get("id")
+        return f"https://foursquare.com/user/{self.account.extra_data.get('id')}"
 
     def get_avatar_url(self):
         return self.account.extra_data.get("photo")
