@@ -18,15 +18,10 @@ class FoursquareOAuth2Adapter(OAuth2Adapter):
         # Foursquare needs a version number for their API requests as
         # documented here
         # https://developer.foursquare.com/overview/versioning
-        resp = (
-            get_adapter()
-            .get_requests_session()
-            .get(
-                self.profile_url,
-                params={"oauth_token": token.token, "v": "20140116"},
-            )
-        )
-        extra_data = resp.json()["response"]["user"]
+        with get_adapter().get_requests_session() as sess:
+            params = {"oauth_token": token.token, "v": "20140116"}
+            resp = sess.get(self.profile_url, params=params)
+            extra_data = resp.json()["response"]["user"]
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
