@@ -12,24 +12,21 @@ class GlobusOAuth2Adapter(OAuth2Adapter):
 
     provider_base_url = "https://auth.globus.org/v2/oauth2"
 
-    access_token_url = "{0}/token".format(provider_base_url)
-    authorize_url = "{0}/authorize".format(provider_base_url)
-    profile_url = "{0}/userinfo".format(provider_base_url)
+    access_token_url = f"{provider_base_url}/token"
+    authorize_url = f"{provider_base_url}/authorize"
+    profile_url = f"{provider_base_url}/userinfo"
 
     def complete_login(self, request, app, token, response):
-        extra_data = (
-            get_adapter()
-            .get_requests_session()
-            .get(
+        headers = {"Authorization": f"Bearer {token.token}"}
+        with get_adapter().get_requests_session() as sess:
+            resp = sess.get(
                 self.profile_url,
                 params={"access_token": token.token},
-                headers={
-                    "Authorization": "Bearer " + token.token,
-                },
+                headers=headers,
             )
-        )
+            extra_data = resp.json()
 
-        return self.get_provider().sociallogin_from_response(request, extra_data.json())
+        return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
 oauth2_login = OAuth2LoginView.adapter_view(GlobusOAuth2Adapter)
