@@ -7,7 +7,8 @@ class InstagramAccount(ProviderAccount):
     PROFILE_URL = "https://instagram.com/"
 
     def get_profile_url(self):
-        return self.PROFILE_URL + self.account.extra_data.get("username")
+        username = self.account.extra_data.get("username")
+        return f"{self.PROFILE_URL}{username}"
 
 
 class InstagramProvider(OAuth2Provider):
