@@ -17,11 +17,11 @@ class MiroOAuth2Adapter(OAuth2Adapter):
             "Authorization": f"Bearer {token.token}",
             "Content-Type": "application/json",
         }
-        extra_data = (
-            get_adapter().get_requests_session().get(self.profile_url, headers=headers)
-        )
-        extra_data.raise_for_status()
-        return self.get_provider().sociallogin_from_response(request, extra_data.json())
+        with get_adapter().get_requests_session() as sess:
+            resp = sess.get(self.profile_url, headers=headers)
+            resp.raise_for_status()
+            extra_data = resp.json()
+        return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
 oauth2_login = OAuth2LoginView.adapter_view(MiroOAuth2Adapter)
