@@ -13,12 +13,11 @@ class NaverOAuth2Adapter(OAuth2Adapter):
     profile_url = "https://openapi.naver.com/v1/nid/me"
 
     def complete_login(self, request, app, token, **kwargs):
-        headers = {"Authorization": "Bearer {0}".format(token.token)}
-        resp = (
-            get_adapter().get_requests_session().get(self.profile_url, headers=headers)
-        )
-        resp.raise_for_status()
-        extra_data = resp.json().get("response")
+        headers = {"Authorization": f"Bearer {token.token}"}
+        with get_adapter().get_requests_session() as sess:
+            resp = sess.get(self.profile_url, headers=headers)
+            resp.raise_for_status()
+            extra_data = resp.json().get("response")
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
