@@ -7,10 +7,8 @@ from allauth.socialaccount.providers.openstreetmap.views import (
 
 class OpenStreetMapAccount(ProviderAccount):
     def get_profile_url(self):
-        return (
-            "https://www.openstreetmap.org/user/"
-            + self.account.extra_data["display_name"]
-        )
+        display_name = self.account.extra_data["display_name"]
+        return f"https://www.openstreetmap.org/user/{display_name}"
 
     def get_avatar_url(self):
         ret = None
