@@ -12,17 +12,17 @@ class PaypalOAuth2Adapter(OAuth2Adapter):
     @property
     def authorize_url(self):
         path = "webapps/auth/protocol/openidconnect/v1/authorize"
-        return "https://www.{0}/{1}".format(self._get_endpoint(), path)
+        return f"https://www.{self._get_endpoint()}/{path}"
 
     @property
     def access_token_url(self):
         path = "v1/identity/openidconnect/tokenservice"
-        return "https://api.{0}/{1}".format(self._get_endpoint(), path)
+        return f"https://api.{self._get_endpoint()}/{path}"
 
     @property
     def profile_url(self):
         path = "v1/identity/openidconnect/userinfo"
-        return "https://api.{0}/{1}".format(self._get_endpoint(), path)
+        return f"https://api.{self._get_endpoint()}/{path}"
 
     def _get_endpoint(self):
         settings = self.get_provider().get_settings()
@@ -32,15 +32,12 @@ class PaypalOAuth2Adapter(OAuth2Adapter):
             return "sandbox.paypal.com"
 
     def complete_login(self, request, app, token, **kwargs):
-        response = (
-            get_adapter()
-            .get_requests_session()
-            .post(
+        with get_adapter().get_requests_session() as sess:
+            response = sess.post(
                 self.profile_url,
                 params={"schema": "openid", "access_token": token.token},
             )
-        )
-        extra_data = response.json()
+            extra_data = response.json()
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
