@@ -14,12 +14,10 @@ class WeiboOAuth2Adapter(OAuth2Adapter):
 
     def complete_login(self, request, app, token, **kwargs):
         uid = kwargs.get("response", {}).get("uid")
-        resp = (
-            get_adapter()
-            .get_requests_session()
-            .get(self.profile_url, params={"access_token": token.token, "uid": uid})
-        )
-        extra_data = resp.json()
+        with get_adapter().get_requests_session() as sess:
+            params = {"access_token": token.token, "uid": uid}
+            resp = sess.get(self.profile_url, params=params)
+            extra_data = resp.json()
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
